@@ -1,5 +1,5 @@
 """
-low level ebuild processor.
+low level ebuild processor
 
 This basically is a coprocessor that controls a bash daemon for actual
 ebuild execution. Via this, the bash side can reach into the python
@@ -41,7 +41,7 @@ inactive_ebp_list = []
 active_ebp_list = []
 
 
-def _single_thread_allowed(functor):
+def _singled_threaded(functor):
     """Decorator that forces method to run under single thread."""
     @wraps(functor)
     def _inner(*args, **kwargs):
@@ -50,13 +50,7 @@ def _single_thread_allowed(functor):
     return _inner
 
 
-@_single_thread_allowed
-def forget_all_processors():
-    active_ebp_list[:] = []
-    inactive_ebp_list[:] = []
-
-
-@_single_thread_allowed
+@_singled_threaded
 def shutdown_all_processors():
     """Kill all known processors."""
     try:
@@ -82,7 +76,7 @@ def shutdown_all_processors():
 spawn.atexit_register(shutdown_all_processors)
 
 
-@_single_thread_allowed
+@_singled_threaded
 def request_ebuild_processor(userpriv=False, sandbox=None, fd_pipes=None):
     """Request a processor instance, creating a new one if needed.
 
@@ -96,7 +90,7 @@ def request_ebuild_processor(userpriv=False, sandbox=None, fd_pipes=None):
         sandbox = spawn.is_sandbox_capable()
 
     for ebp in inactive_ebp_list:
-        if ebp.userprived() == userpriv and (ebp.sandboxed() or not sandbox):
+        if ebp.userpriv == userpriv and (ebp.sandbox or not sandbox):
             if not ebp.is_responsive:
                 inactive_ebp_list.remove(ebp)
                 continue
@@ -110,7 +104,7 @@ def request_ebuild_processor(userpriv=False, sandbox=None, fd_pipes=None):
     return ebp
 
 
-@_single_thread_allowed
+@_singled_threaded
 def release_ebuild_processor(ebp):
     """Release a given processor instance and shut it down if necessary.
 
@@ -130,16 +124,15 @@ def release_ebuild_processor(ebp):
         return False
 
     assert ebp not in inactive_ebp_list
-    # We can't reuse processors that use custom fd mappings or are locked on
-    # release for one reason or another.
-    if ebp.is_locked or ebp._fd_pipes:
+    # shutdown processors that can't be reused
+    if ebp.is_locked or ebp.custom_fds:
         ebp.shutdown_processor()
     else:
         inactive_ebp_list.append(ebp)
     return True
 
 
-@_single_thread_allowed
+@_singled_threaded
 def drop_ebuild_processor(ebp):
     """Force a given processor to be dropped from active/inactive lists.
 
@@ -275,9 +268,6 @@ def chuck_KeyboardInterrupt(*args):
     raise KeyboardInterrupt("ctrl+c encountered")
 
 
-signal.signal(signal.SIGINT, chuck_KeyboardInterrupt)
-
-
 def chuck_TermInterrupt(ebp, *args):
     """Event handler for SIGTERM."""
     if ebp is None:
@@ -292,7 +282,9 @@ def chuck_TermInterrupt(ebp, *args):
         ebp.shutdown_processor()
 
 
+# register signal handlers for ebd cleanup
 signal.signal(signal.SIGTERM, partial(chuck_TermInterrupt, None))
+signal.signal(signal.SIGINT, chuck_KeyboardInterrupt)
 
 
 def chuck_UnhandledCommand(ebp, line):
@@ -306,8 +298,7 @@ def chuck_StoppingCommand(ebp, line):
     if args[0] == 'succeeded':
         raise FinishedProcessing(True)
     else:
-        # Note that we want failures missing an error message to raise
-        # IndexError here so they can be fixed on the bash side.
+        # IndexError is explicitly left unhandled to force visibility
         raise ProcessorError(args[1])
 
 
@@ -325,39 +316,30 @@ class EbuildProcessor:
         """
         self.lock()
         self.ebd = e_const.EBUILD_DAEMON_PATH
-        spawn_opts = {'umask': 0o002}
+        self.sandbox = sandbox
+        self.userpriv = userpriv
+        self.custom_fds = fd_pipes
 
         self._preloaded_eclasses = {}
         self._eclass_caching = False
         self._outstanding_expects = []
         self._metadata_paths = None
 
-        if userpriv:
-            self.__userpriv = True
+        spawn_opts = {'umask': 0o002}
+        if self.userpriv:
             spawn_opts.update({
                 "uid": os_data.portage_uid,
                 "gid": os_data.portage_gid,
                 "groups": [os_data.portage_gid],
             })
-        else:
-            if spawn.is_userpriv_capable():
-                spawn_opts.update({
-                    "gid": os_data.portage_gid,
-                    "groups": [0, os_data.portage_gid],
-                })
-            self.__userpriv = False
+        elif spawn.is_userpriv_capable():
+            spawn_opts.update({
+                "gid": os_data.portage_gid,
+                "groups": [0, os_data.portage_gid],
+            })
 
-        # open the pipes to be used for chatting with the new daemon
-        cread, cwrite = os.pipe()
-        dread, dwrite = os.pipe()
-        self.__sandbox = False
-
-        self._fd_pipes = fd_pipes if fd_pipes is not None else {}
-
-        # since it's questionable which spawn method we'll use (if
-        # sandbox fex), we ensure the bashrc is invalid.
-        env = {x: "/etc/portage/spork/not/valid/ha/ha"
-               for x in ("BASHRC", "BASH_ENV")}
+        # force invalid bashrc
+        env = {x: "/not/valid" for x in ("BASHRC", "BASH_ENV")}
 
         if int(os.environ.get('PKGCORE_PERF_DEBUG', 0)):
             env["PKGCORE_PERF_DEBUG"] = os.environ['PKGCORE_PERF_DEBUG']
@@ -369,12 +351,10 @@ class EbuildProcessor:
         env["PATH"] = os.pathsep.join(
             list(const.PATH_FORCED_PREPEND) + [os.environ["PATH"]])
 
-        if sandbox:
+        if self.sandbox:
             if not spawn.is_sandbox_capable():
                 raise ValueError("spawn lacks sandbox capabilities")
-            self.__sandbox = True
             spawn_func = spawn.spawn_sandbox
-#            env.update({"SANDBOX_DEBUG":"1", "SANDBOX_DEBUG_LOG":"/var/tmp/test"})
         else:
             spawn_func = spawn.spawn
 
@@ -382,22 +362,28 @@ class EbuildProcessor:
         # ran from a nonexistent dir
         spawn_opts["cwd"] = e_const.EBD_PATH
 
-        # Force the pipes to be high up fd wise so nobody stupidly hits 'em, we
-        # start from max-3 to avoid a bug in older bash where it doesn't check
-        # if an fd is in use before claiming it.
+        # Use high numbered fds for pipes to avoid external usage collisions
+        # starting with max-3 to avoid a bug in older bash versions where it
+        # doesn't check if an fd is in use before claiming it.
         max_fd = min(spawn.max_fd_limit, 1024)
         env.update({
-            "PKGCORE_EBD_READ_FD": str(max_fd-4),
-            "PKGCORE_EBD_WRITE_FD": str(max_fd-3),
+            "PKGCORE_EBD_READ_FD": str(max_fd - 4),
+            "PKGCORE_EBD_WRITE_FD": str(max_fd - 3),
         })
 
-        # allow any pipe overrides except the ones we use to communicate
-        ebd_pipes = {0: 0, 1: 1, 2: 2}
-        ebd_pipes.update(self._fd_pipes)
-        ebd_pipes.update({max_fd-4: cread, max_fd-3: dwrite})
+        # open pipes used for communication
+        cread, cwrite = os.pipe()
+        dread, dwrite = os.pipe()
 
-        # pgid=0: Each processor is the process group leader for all its
-        # spawned children so everything can be terminated easily if necessary.
+        # allow pipe overrides except ebd-related
+        ebd_pipes = {0: 0, 1: 1, 2: 2}
+        if fd_pipes:
+            ebd_pipes.update(fd_pipes)
+        ebd_pipes[max_fd - 4] = cread
+        ebd_pipes[max_fd - 3] = dwrite
+
+        # force each ebd instance to be a process group leader so everything
+        # can be easily terminated
         self.pid = spawn_func(
             [spawn.BASH_BINARY, self.ebd, "daemonize"],
             fd_pipes=ebd_pipes, returnpid=True, env=env, pgid=0, **spawn_opts)[0]
@@ -407,15 +393,12 @@ class EbuildProcessor:
         self.ebd_write = os.fdopen(cwrite, "w")
         self.ebd_read = os.fdopen(dread, "r")
 
-        # basically a quick "yo" to the daemon
-        self.write("dude?")
-        if not self.expect("dude!"):
-            logger.error("error in server coms, bailing.")
-            raise InternalError(
-                "expected 'dude!' response from ebd, which wasn't received. "
-                "likely a bug")
+        # verify ebd is running
+        self.write("ebd?")
+        if not self.expect("ebd!"):
+            raise InternalError("expected 'ebd!' response from ebd, which wasn't received")
 
-        if self.__sandbox:
+        if self.sandbox:
             self.write("sandbox_log?")
             self.__sandbox_log = self.read().split()[0]
         else:
@@ -451,14 +434,6 @@ class EbuildProcessor:
         self.write("start_processing")
         return self.generic_handler(additional_commands=additional_commands)
 
-    def sandboxed(self):
-        """Is this instance sandboxed?"""
-        return self.__sandbox
-
-    def userprived(self):
-        """Is this instance userprived?"""
-        return self.__userpriv
-
     def write(self, string, flush=True, disable_runtime_exceptions=False,
               append_newline=True):
         """Send something to the bash side.
@@ -474,7 +449,6 @@ class EbuildProcessor:
             if append_newline:
                 if string != '\n':
                     string += "\n"
-            #logger.debug("wrote %i: %s" % (len(string), string))
             self.ebd_write.write(string)
             if flush:
                 self.ebd_write.flush()
@@ -522,7 +496,7 @@ class EbuildProcessor:
         self._outstanding_expects.append((flush, want))
         return self._consume_async_expects()
 
-    def readlines(self, lines, ignore_killed=False):
+    def readlines(self, lines):
         mydata = []
         while lines > 0:
             mydata.append(self.ebd_read.readline())
@@ -536,12 +510,12 @@ class EbuildProcessor:
             lines -= 1
         return mydata
 
-    def read(self, lines=1, ignore_killed=False):
+    def read(self, lines=1):
         """Read data from the daemon.
 
         Shouldn't be called except internally.
         """
-        return "\n".join(self.readlines(lines, ignore_killed=ignore_killed))
+        return "\n".join(self.readlines(lines))
 
     def sandbox_summary(self, move_log=False):
         """If the instance is sandboxed, print the sandbox access summary.
@@ -701,7 +675,7 @@ class EbuildProcessor:
             if kill:
                 os.killpg(self.pid, signal.SIGKILL)
 
-            # now we wait for the process group
+            # wait for the process group
             try:
                 os.waitpid(-self.pid, 0)
             except KeyboardInterrupt:
@@ -734,7 +708,7 @@ class EbuildProcessor:
                 data.append("%s=$'%s'" % (key, val.replace("'", "\\'")))
 
         # TODO: Move to using unprefixed lines to avoid leaking internal
-        # variables to spawned commands once we use builtins for all commands
+        # variables to spawned commands once builtins are used for all commands
         # currently using pkgcore-ebuild-helper.
         return f"export {' '.join(data)}"
 
